#!/usr/bin/env python

import argparse
#import cmd2
import os
import sys

#Premable - grab the args


parser = argparse.ArgumentParser(description="Maintain a list of needful things to do.")
group = parser.add_mutually_exclusive_group()

parser.add_argument("-t","--task", type=str, help="Add a new task to the list - use single or double quotes")
group.add_argument("-d", "--done", type=int, help="Complete a task")
group.add_argument("-x", "--skip", type= int, help="Skip a task")
group.add_argument("-s", "--show", type= int, help="Show a (specific) task")
group.add_argument("-q", "--quit", type= int, help="Show a (specific) task")

args = parser.parse_args()
task = args.task

#print(17,repr(task))

#Build and maintain the list
    
    

tasklist = []
    
tasklist.append(task)

#print(25,repr(tasklist)) 


#Show the current tasks

print('\n')
os.system('date')
print('\n')
os.system('cal')
print('\n')
    

#for i in tasklist:
#    print(f'{i}' + ': ' + tasklist[i])

[print(i) for i in tasklist] 

#print(task)
print('\n')





#!/usr/bin/env python

import argparse
#import cmd2
import os
import sys

import typer

# No arg

#def main():
#    print("Hello World")

# One arg

#def main(name: str):
#    print(f"Hello {name}")

# Two args
    
#def main(name: str, lastname: str):
#    print(f"Hello {name} {lastname}")
    
# Optional, bool

#def main(name: str, lastname: str, formal: bool = False):
#    if formal:
#        print(f"Good day Ms. {name} {lastname}.")
#    else:
#        print(f"Hello {name} {lastname}")
        
# Optional, 2nd arg

def main(name: str, lastname: str = "", formal: bool = False):
    """
    Say hi to NAME, optionally with a --lastname.

    If --formal is used, say hi very formally.
    """
    if formal:
        print(f"Good day Ms. {name} {lastname}.")
    else:
        print(f"Hello {name} {lastname}")

if __name__ == "__main__":
    typer.run(main)



#!/usr/bin/env python

import argparse
#import cmd2
import os
import sys

#Premable - grab the args

if __name__ == '__main__':

    parser = argparse.ArgumentParser(description="Maintain a list of needful things to do.")
    group = parser.add_mutually_exclusive_group()

    parser.add_argument("-t","--task", type=str, help="Add a new task to the list - use single or double quotes")
    group.add_argument("-d", "--done", type=int, help="Complete a task")
    group.add_argument("-x", "--skip", type= int, help="Skip a task")
    group.add_argument("-s", "--show", type= int, help="Show a (specific) task")

    args = parser.parse_args()
    task = args.task

    #print(17,repr(task))

    #Build and maintain the list

    tasklist = []
    
    tasklist.append(task)

    #print(25,repr(tasklist)) 


    #Show the current tasks

    print('\n')
    os.system('date')
    print('\n')
    os.system('cal')
    print('\n')
    

    #for i in tasklist:
	#    print(f'{i}' + ': ' + tasklist[i])
	
    [print(i) for i in tasklist] 

    #print(task)	
    print('\n')





# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['tasket']

package_data = \
{'': ['*']}

install_requires = \
['SQLAlchemy>=1.4.40,<2.0.0',
 'click>=8.1.3,<9.0.0',
 'coverage[toml]>=6.4.4,<7.0.0',
 'rich>=12.5.1,<13.0.0',
 'typer[all]>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['tasket = tasket.main:app']}

setup_kwargs = {
    'name': 'tasket',
    'version': '0.0.4',
    'description': 'Maintain a list of needful things to do.',
    'long_description': None,
    'author': 'Damien Calloway',
    'author_email': 'damiencalloway@fastmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
